@@ -1,6 +1,7 @@
 from __future__ import annotations
-from typing import Final
+from typing import Final, Pattern
 import os
+import re
 
 
 NEW_LINE: Final[str] = '\n'
@@ -11,7 +12,6 @@ DOCTEST: Final[str] = '>>>'
 SLICE_SEP: Final[str] = ':'
 SH_SEP: Final[str | None] = os.environ.get('IFS')
 
-LOWEST: Final[int] = 0
 START_INDEX: Final[int] = 0
 MIN_TIMES: Final[int] = 1
 FIRST: Final[int] = 1
@@ -25,4 +25,5 @@ SKIP: Final[None] = None
 NO_ITEMS: Final[Ellipsis] = ...
 
 NO_CMD_ERR: Final[str] = "This command isn't implemented."
-WHITESPACE_RE: Final[str] = r'\s'
+WHITESPACE_RE: Final[Pattern[str]] = re.compile(r'\s')
+LOWEST: Final[int] = 0
